@@ -51,9 +51,7 @@ class CodePipeline(Base):
 
         self.client = self.session.client(
             "codepipeline",
-            config=botocore.config.Config(
-                connect_timeout=5, retries={"max_attempts": 0}
-            ),
+            config=botocore.config.Config(connect_timeout=5, retries={"max_attempts": 0}),
         )
 
         self.pipelines = []
@@ -233,9 +231,7 @@ class CodePipeline(Base):
                     "revisionSummary", "NA"
                 )
 
-            summary["sourceSummary"] = (
-                summary["sourceSummary"].replace("\n", " ").strip()
-            )
+            summary["sourceSummary"] = summary["sourceSummary"].replace("\n", " ").strip()
 
         return summaries
 
@@ -417,9 +413,7 @@ class CodePipeline(Base):
             for rev in stage.get("latestExecutionDetails", {}).get(
                 "artifactRevisions", []
             ):
-                rev_summry.append(
-                    rev.get("revisionSummary", "NA").split("\n")[0].strip()
-                )
+                rev_summry.append(rev.get("revisionSummary", "NA").split("\n")[0].strip())
             rev_summry = " / ".join(rev_summry)
 
             print(
@@ -632,7 +626,6 @@ class CodePipeline(Base):
             )
 
         if status == "Failed":
-
             if action_provider == "CodeBuild":
                 key = o7i.input_string("Option -> Retry(r) Details(d) Back (any) :")
             else:
@@ -757,9 +750,7 @@ class CodePipeline(Base):
         obj.add_option(
             o7m.Option(key="e", short="Executions List", callback=self.menu_executions)
         )
-        obj.add_option(
-            o7m.Option(key="s", short="Start", callback=self.start_execution)
-        )
+        obj.add_option(o7m.Option(key="s", short="Start", callback=self.start_execution))
         obj.add_option(
             o7m.Option(
                 key="int",
