@@ -31,17 +31,16 @@
 # --------------------------------
 #
 # --------------------------------
-import pprint
 import logging
+import pprint
 import subprocess
 
-from o7util.table import TableParam, ColumnParam, Table
-import o7util.menu as o7m
 import o7util.input as o7i
+import o7util.menu as o7m
+from o7util.table import ColumnParam, Table, TableParam
 
 from o7cli.base import Base
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -201,9 +200,7 @@ class Ecs(Base):
                 ColumnParam(
                     title="Pending Task", type="int", data_col="pendingTasksCount"
                 ),
-                ColumnParam(
-                    title="Services", type="int", data_col="activeServicesCount"
-                ),
+                ColumnParam(title="Services", type="int", data_col="activeServicesCount"),
                 ColumnParam(
                     title="Instances",
                     type="int",
@@ -386,11 +383,12 @@ class Ecs(Base):
         if key is None or key < 0 or key >= len(containers):
             return
 
-        proc_cmd = f"aws --region {self.session.region_name} ecs execute-command "
-        proc_cmd += f'--cluster {cluster} --task {task["taskId"]} --container {containers[key]["name"]} '
-        proc_cmd += f'--command "{cmd}" --interactive'
-        print(f"Command: {proc_cmd}")
-        subprocess.call(proc_cmd, shell=True)
+        cmds = f"aws --region {self.session.region_name} ecs execute-command"
+        cmds += f" --cluster {cluster} --task {task['taskId']} --container {containers[key]['name']}"
+        cmds += f" --command {cmd} --interactive"
+
+        print(f"Commands: {cmds}")
+        subprocess.call(cmds.split(" "), shell=False)  # noqa: S603
 
     # *************************************************
     #
@@ -543,7 +541,6 @@ def menu(**kwargs):
 #
 # *************************************************
 if __name__ == "__main__":
-
     logging.basicConfig(
         level=logging.INFO, format="[%(levelname)-5.5s] [%(name)s] %(message)s"
     )
