@@ -88,7 +88,6 @@ class Logstream(Base):
         done = False
         count = 0
         while not done:
-
             if self.from_head and self.next_token is not None:
                 param["nextToken"] = self.next_token
             if not self.from_head and self.prev_token is not None:
@@ -169,9 +168,7 @@ class Logstream(Base):
         else:
             direction = f"{len(self.events)} to Last"
 
-        return (
-            f"{COLOR_HEADER}{direction} | Max per Load: {self.max_per_load}{COLOR_END}"
-        )
+        return f"{COLOR_HEADER}{direction} | Max per Load: {self.max_per_load}{COLOR_END}"
 
     # *************************************************
     #
@@ -266,7 +263,6 @@ class Logstream(Base):
 #
 # *************************************************
 if __name__ == "__main__":
-
     logging.basicConfig(
         level=logging.INFO, format="[%(levelname)-5.5s] [%(name)s] %(message)s"
     )
